/* Generated by wayland-scanner 1.20.0 */

#ifndef INPUT_METHOD_CLIENT_PROTOCOL_H
#define INPUT_METHOD_CLIENT_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-client.h"

#ifdef  __cplusplus
extern "C" {
#endif

/**
 * @page page_input_method The input_method protocol
 * @section page_ifaces_input_method Interfaces
 * - @subpage page_iface_input_method_context - input method context
 * - @subpage page_iface_input_method - input method
 * - @subpage page_iface_input_panel - interface for implementing keyboards
 * - @subpage page_iface_input_panel_surface - 
 * @section page_copyright_input_method Copyright
 * <pre>
 *
 * Copyright © 2012 Intel Corporation
 * Copyright © 2013-2020 LG Electronics, Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that the above copyright notice appear in
 * all copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of
 * the copyright holders not be used in advertising or publicity
 * pertaining to distribution of the software without specific,
 * written prior permission.  The copyright holders make no
 * representations about the suitability of this software for any
 * purpose.  It is provided "as is" without express or implied
 * warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS, IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 * THIS SOFTWARE.
 * </pre>
 */
struct input_method;
struct input_method_context;
struct input_panel;
struct input_panel_surface;
struct wl_keyboard;
struct wl_surface;

#ifndef INPUT_METHOD_CONTEXT_INTERFACE
#define INPUT_METHOD_CONTEXT_INTERFACE
/**
 * @page page_iface_input_method_context input_method_context
 * @section page_iface_input_method_context_desc Description
 *
 * Corresponds to a text model on input method side. An input method context
 * is created on text mode activation on the input method side. It allows to
 * receive information about the text model from the application via events.
 * Input method contexts do not keep state after deactivation and should be
 * destroyed after deactivation is handled.
 * @section page_iface_input_method_context_api API
 * See @ref iface_input_method_context.
 */
/**
 * @defgroup iface_input_method_context The input_method_context interface
 *
 * Corresponds to a text model on input method side. An input method context
 * is created on text mode activation on the input method side. It allows to
 * receive information about the text model from the application via events.
 * Input method contexts do not keep state after deactivation and should be
 * destroyed after deactivation is handled.
 */
extern const struct wl_interface input_method_context_interface;
#endif
#ifndef INPUT_METHOD_INTERFACE
#define INPUT_METHOD_INTERFACE
/**
 * @page page_iface_input_method input_method
 * @section page_iface_input_method_desc Description
 *
 * An input method object is responsible to compose text in response to
 * input from hardware or virtual keyboards. There is one input method
 * object per seat. On activate there is a new input method context object
 * created which allows the input method to communicate with the text model.
 * @section page_iface_input_method_api API
 * See @ref iface_input_method.
 */
/**
 * @defgroup iface_input_method The input_method interface
 *
 * An input method object is responsible to compose text in response to
 * input from hardware or virtual keyboards. There is one input method
 * object per seat. On activate there is a new input method context object
 * created which allows the input method to communicate with the text model.
 */
extern const struct wl_interface input_method_interface;
#endif
#ifndef INPUT_PANEL_INTERFACE
#define INPUT_PANEL_INTERFACE
/**
 * @page page_iface_input_panel input_panel
 * @section page_iface_input_panel_desc Description
 *
 * Only one client can bind this interface at a time.
 * @section page_iface_input_panel_api API
 * See @ref iface_input_panel.
 */
/**
 * @defgroup iface_input_panel The input_panel interface
 *
 * Only one client can bind this interface at a time.
 */
extern const struct wl_interface input_panel_interface;
#endif
#ifndef INPUT_PANEL_SURFACE_INTERFACE
#define INPUT_PANEL_SURFACE_INTERFACE
/**
 * @page page_iface_input_panel_surface input_panel_surface
 * @section page_iface_input_panel_surface_api API
 * See @ref iface_input_panel_surface.
 */
/**
 * @defgroup iface_input_panel_surface The input_panel_surface interface
 */
extern const struct wl_interface input_panel_surface_interface;
#endif

/**
 * @ingroup iface_input_method_context
 * @struct input_method_context_listener
 */
struct input_method_context_listener {
	/**
	 * surrounding text event
	 *
	 * The plain surrounding text around the input position. Cursor
	 * is the position within the surrounding text. Anchor is the
	 * position of the selection anchor within the surrounding text. If
	 * there is no selected text anchor is the same as cursor.
	 */
	void (*surrounding_text)(void *data,
				 struct input_method_context *input_method_context,
				 const char *text,
				 uint32_t cursor,
				 uint32_t anchor);
	/**
	 * reset
	 *
	 * Resets the input state.
	 */
	void (*reset)(void *data,
		      struct input_method_context *input_method_context,
		      uint32_t serial);
	/**
	 * set content purpose and hint
	 *
	 * Sets the content purpose and content hint.
	 */
	void (*content_type)(void *data,
			     struct input_method_context *input_method_context,
			     uint32_t hint,
			     uint32_t purpose);
	/**
	 * invoke action
	 *
	 * Invokes a button action on a given position.
	 *
	 * Not implemented.
	 */
	void (*invoke_action)(void *data,
			      struct input_method_context *input_method_context,
			      uint32_t button,
			      uint32_t index);
	/**
	 * commit state
	 *
	 * Requests to apply state changes sent so far.
	 */
	void (*commit)(void *data,
		       struct input_method_context *input_method_context);
	/**
	 * set max length of input field
	 *
	 * Notifies the maximum length of an input field.
	 */
	void (*max_text_length)(void *data,
				struct input_method_context *input_method_context,
				uint32_t length);
	/**
	 * set platform specific data
	 *
	 * Notifies the platform specific data (text).
	 */
	void (*platform_data)(void *data,
			      struct input_method_context *input_method_context,
			      const char *text);
	/**
	 * set type of enter key
	 *
	 * Sets the type of the enter key on an input panel (virtual
	 * keyboard).
	 */
	void (*enter_key_type)(void *data,
			       struct input_method_context *input_method_context,
			       uint32_t enter_key_type);
};

/**
 * @ingroup iface_input_method_context
 */
static inline int
input_method_context_add_listener(struct input_method_context *input_method_context,
				  const struct input_method_context_listener *listener, void *data)
{
	return wl_proxy_add_listener((struct wl_proxy *) input_method_context,
				     (void (**)(void)) listener, data);
}

#define INPUT_METHOD_CONTEXT_DESTROY 0
#define INPUT_METHOD_CONTEXT_COMMIT_STRING 1
#define INPUT_METHOD_CONTEXT_PREEDIT_STRING 2
#define INPUT_METHOD_CONTEXT_PREEDIT_STYLING 3
#define INPUT_METHOD_CONTEXT_PREEDIT_CURSOR 4
#define INPUT_METHOD_CONTEXT_DELETE_SURROUNDING_TEXT 5
#define INPUT_METHOD_CONTEXT_CURSOR_POSITION 6
#define INPUT_METHOD_CONTEXT_MODIFIERS_MAP 7
#define INPUT_METHOD_CONTEXT_KEYSYM 8
#define INPUT_METHOD_CONTEXT_GRAB_KEYBOARD 9
#define INPUT_METHOD_CONTEXT_KEY 10
#define INPUT_METHOD_CONTEXT_MODIFIERS 11

/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_SURROUNDING_TEXT_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_RESET_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_CONTENT_TYPE_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_INVOKE_ACTION_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_COMMIT_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_MAX_TEXT_LENGTH_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_PLATFORM_DATA_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_ENTER_KEY_TYPE_SINCE_VERSION 1

/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_COMMIT_STRING_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_PREEDIT_STRING_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_PREEDIT_STYLING_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_PREEDIT_CURSOR_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_DELETE_SURROUNDING_TEXT_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_CURSOR_POSITION_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_MODIFIERS_MAP_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_KEYSYM_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_GRAB_KEYBOARD_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_KEY_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_MODIFIERS_SINCE_VERSION 1

/** @ingroup iface_input_method_context */
static inline void
input_method_context_set_user_data(struct input_method_context *input_method_context, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) input_method_context, user_data);
}

/** @ingroup iface_input_method_context */
static inline void *
input_method_context_get_user_data(struct input_method_context *input_method_context)
{
	return wl_proxy_get_user_data((struct wl_proxy *) input_method_context);
}

static inline uint32_t
input_method_context_get_version(struct input_method_context *input_method_context)
{
	return wl_proxy_get_version((struct wl_proxy *) input_method_context);
}

/**
 * @ingroup iface_input_method_context
 *
 * Destroys the input method context object.
 */
static inline void
input_method_context_destroy(struct input_method_context *input_method_context)
{
	wl_proxy_marshal_flags((struct wl_proxy *) input_method_context,
			 INPUT_METHOD_CONTEXT_DESTROY, NULL, wl_proxy_get_version((struct wl_proxy *) input_method_context), WL_MARSHAL_FLAG_DESTROY);
}

/**
 * @ingroup iface_input_method_context
 *
 * Sends the commit string text to the applications text model.
 */
static inline void
input_method_context_commit_string(struct input_method_context *input_method_context, uint32_t serial, const char *text)
{
	wl_proxy_marshal_flags((struct wl_proxy *) input_method_context,
			 INPUT_METHOD_CONTEXT_COMMIT_STRING, NULL, wl_proxy_get_version((struct wl_proxy *) input_method_context), 0, serial, text);
}

/**
 * @ingroup iface_input_method_context
 *
 * Sends the pre-edit string text to the applications text model.
 */
static inline void
input_method_context_preedit_string(struct input_method_context *input_method_context, uint32_t serial, const char *text, const char *commit)
{
	wl_proxy_marshal_flags((struct wl_proxy *) input_method_context,
			 INPUT_METHOD_CONTEXT_PREEDIT_STRING, NULL, wl_proxy_get_version((struct wl_proxy *) input_method_context), 0, serial, text, commit);
}

/**
 * @ingroup iface_input_method_context
 *
 * Sets styling information on composing text. The style is applied for
 * length (in bytes) characters from index relative to the beginning of
 * the composing text (as byte index). Multiple styles can be applied
 * to a composing text.
 */
static inline void
input_method_context_preedit_styling(struct input_method_context *input_method_context, uint32_t serial, uint32_t index, uint32_t length, uint32_t style)
{
	wl_proxy_marshal_flags((struct wl_proxy *) input_method_context,
			 INPUT_METHOD_CONTEXT_PREEDIT_STYLING, NULL, wl_proxy_get_version((struct wl_proxy *) input_method_context), 0, serial, index, length, style);
}

/**
 * @ingroup iface_input_method_context
 *
 * Sets the cursor position inside the composing text (as byte index)
 * relative to the start of the composing text.
 */
static inline void
input_method_context_preedit_cursor(struct input_method_context *input_method_context, uint32_t serial, int32_t index)
{
	wl_proxy_marshal_flags((struct wl_proxy *) input_method_context,
			 INPUT_METHOD_CONTEXT_PREEDIT_CURSOR, NULL, wl_proxy_get_version((struct wl_proxy *) input_method_context), 0, serial, index);
}

/**
 * @ingroup iface_input_method_context
 *
 * Deletes the surrounding text.
 */
static inline void
input_method_context_delete_surrounding_text(struct input_method_context *input_method_context, uint32_t serial, int32_t index, uint32_t length)
{
	wl_proxy_marshal_flags((struct wl_proxy *) input_method_context,
			 INPUT_METHOD_CONTEXT_DELETE_SURROUNDING_TEXT, NULL, wl_proxy_get_version((struct wl_proxy *) input_method_context), 0, serial, index, length);
}

/**
 * @ingroup iface_input_method_context
 *
 * Sets the cursor or anchor position.
 *
 * Not implemented.
 */
static inline void
input_method_context_cursor_position(struct input_method_context *input_method_context, uint32_t serial, int32_t index, int32_t anchor)
{
	wl_proxy_marshal_flags((struct wl_proxy *) input_method_context,
			 INPUT_METHOD_CONTEXT_CURSOR_POSITION, NULL, wl_proxy_get_version((struct wl_proxy *) input_method_context), 0, serial, index, anchor);
}

/**
 * @ingroup iface_input_method_context
 *
 * Transfers an array of 0-terminated modifiers names. The position in
 * the array is the index of the modifier as used in the modifiers
 * bitmask in the keysym event.
 */
static inline void
input_method_context_modifiers_map(struct input_method_context *input_method_context, struct wl_array *map)
{
	wl_proxy_marshal_flags((struct wl_proxy *) input_method_context,
			 INPUT_METHOD_CONTEXT_MODIFIERS_MAP, NULL, wl_proxy_get_version((struct wl_proxy *) input_method_context), 0, map);
}

/**
 * @ingroup iface_input_method_context
 *
 * Notifies when a key event was sent. Key events should not be used
 * for normal text input operations, which should be done with
 * commit_string, delete_surrounfing_text, etc. The key event follows
 * the wl_keyboard key event convention. State is a XKB keysym, state a
 * wl_keyboard key_state.
 */
static inline void
input_method_context_keysym(struct input_method_context *input_method_context, uint32_t serial, uint32_t time, uint32_t sym, uint32_t state, uint32_t modifiers)
{
	wl_proxy_marshal_flags((struct wl_proxy *) input_method_context,
			 INPUT_METHOD_CONTEXT_KEYSYM, NULL, wl_proxy_get_version((struct wl_proxy *) input_method_context), 0, serial, time, sym, state, modifiers);
}

/**
 * @ingroup iface_input_method_context
 *
 * Allows an input method to receive hardware keyboard input and process
 * key events to generate text events (with pre-edit) over the wire. This
 * allows input methods which compose multiple key events for inputting
 * text like it is done for CJK languages.
 */
static inline struct wl_keyboard *
input_method_context_grab_keyboard(struct input_method_context *input_method_context)
{
	struct wl_proxy *keyboard;

	keyboard = wl_proxy_marshal_flags((struct wl_proxy *) input_method_context,
			 INPUT_METHOD_CONTEXT_GRAB_KEYBOARD, &wl_keyboard_interface, wl_proxy_get_version((struct wl_proxy *) input_method_context), 0, NULL);

	return (struct wl_keyboard *) keyboard;
}

/**
 * @ingroup iface_input_method_context
 *
 * Forwards a wl_keyboard::key event to the client that was not processed
 * by the input method itself. Should be used when filtering key events
 * with grab_keyboard. The arguments should be the ones from the
 * wl_keyboard::key event.
 */
static inline void
input_method_context_key(struct input_method_context *input_method_context, uint32_t serial, uint32_t time, uint32_t key, uint32_t state)
{
	wl_proxy_marshal_flags((struct wl_proxy *) input_method_context,
			 INPUT_METHOD_CONTEXT_KEY, NULL, wl_proxy_get_version((struct wl_proxy *) input_method_context), 0, serial, time, key, state);
}

/**
 * @ingroup iface_input_method_context
 *
 * Forwards a wl_keyboard::modifiers event to the client that was not
 * processed by the input method itself.  Should be used when filtering
 * key events with grab_keyboard. The arguments should be the ones
 * from the wl_keyboard::modifiers event.
 */
static inline void
input_method_context_modifiers(struct input_method_context *input_method_context, uint32_t serial, uint32_t mods_depressed, uint32_t mods_latched, uint32_t mods_locked, uint32_t group)
{
	wl_proxy_marshal_flags((struct wl_proxy *) input_method_context,
			 INPUT_METHOD_CONTEXT_MODIFIERS, NULL, wl_proxy_get_version((struct wl_proxy *) input_method_context), 0, serial, mods_depressed, mods_latched, mods_locked, group);
}

/**
 * @ingroup iface_input_method
 * @struct input_method_listener
 */
struct input_method_listener {
	/**
	 * activate event
	 *
	 * A text model was activated. Creates an input method context
	 * object which allows communication with the text model.
	 */
	void (*activate)(void *data,
			 struct input_method *input_method,
			 struct input_method_context *id,
			 uint32_t serial);
	/**
	 * activate event
	 *
	 * The text model corresponding to the context argument was
	 * deactivated. The input method context should be destroyed after
	 * deactivation is handled.
	 */
	void (*deactivate)(void *data,
			   struct input_method *input_method,
			   struct input_method_context *context);
	/**
	 * show input panel event
	 *
	 * The text model corresponding that the input panel sets showing
	 */
	void (*show_input_panel)(void *data,
				 struct input_method *input_method,
				 struct input_method_context *context);
	/**
	 * hide input panel event
	 *
	 * The text model corresponding that the input panel sets hiding
	 */
	void (*hide_input_panel)(void *data,
				 struct input_method *input_method,
				 struct input_method_context *context);
};

/**
 * @ingroup iface_input_method
 */
static inline int
input_method_add_listener(struct input_method *input_method,
			  const struct input_method_listener *listener, void *data)
{
	return wl_proxy_add_listener((struct wl_proxy *) input_method,
				     (void (**)(void)) listener, data);
}

#define INPUT_METHOD_SET_DISPLAY_ID 0

/**
 * @ingroup iface_input_method
 */
#define INPUT_METHOD_ACTIVATE_SINCE_VERSION 1
/**
 * @ingroup iface_input_method
 */
#define INPUT_METHOD_DEACTIVATE_SINCE_VERSION 1
/**
 * @ingroup iface_input_method
 */
#define INPUT_METHOD_SHOW_INPUT_PANEL_SINCE_VERSION 1
/**
 * @ingroup iface_input_method
 */
#define INPUT_METHOD_HIDE_INPUT_PANEL_SINCE_VERSION 1

/**
 * @ingroup iface_input_method
 */
#define INPUT_METHOD_SET_DISPLAY_ID_SINCE_VERSION 2

/** @ingroup iface_input_method */
static inline void
input_method_set_user_data(struct input_method *input_method, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) input_method, user_data);
}

/** @ingroup iface_input_method */
static inline void *
input_method_get_user_data(struct input_method *input_method)
{
	return wl_proxy_get_user_data((struct wl_proxy *) input_method);
}

static inline uint32_t
input_method_get_version(struct input_method *input_method)
{
	return wl_proxy_get_version((struct wl_proxy *) input_method);
}

/** @ingroup iface_input_method */
static inline void
input_method_destroy(struct input_method *input_method)
{
	wl_proxy_destroy((struct wl_proxy *) input_method);
}

/**
 * @ingroup iface_input_method
 *
 * Sets the id of the display corresponding.
 */
static inline void
input_method_set_display_id(struct input_method *input_method, uint32_t id)
{
	wl_proxy_marshal_flags((struct wl_proxy *) input_method,
			 INPUT_METHOD_SET_DISPLAY_ID, NULL, wl_proxy_get_version((struct wl_proxy *) input_method), 0, id);
}

#define INPUT_PANEL_GET_INPUT_PANEL_SURFACE 0


/**
 * @ingroup iface_input_panel
 */
#define INPUT_PANEL_GET_INPUT_PANEL_SURFACE_SINCE_VERSION 1

/** @ingroup iface_input_panel */
static inline void
input_panel_set_user_data(struct input_panel *input_panel, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) input_panel, user_data);
}

/** @ingroup iface_input_panel */
static inline void *
input_panel_get_user_data(struct input_panel *input_panel)
{
	return wl_proxy_get_user_data((struct wl_proxy *) input_panel);
}

static inline uint32_t
input_panel_get_version(struct input_panel *input_panel)
{
	return wl_proxy_get_version((struct wl_proxy *) input_panel);
}

/** @ingroup iface_input_panel */
static inline void
input_panel_destroy(struct input_panel *input_panel)
{
	wl_proxy_destroy((struct wl_proxy *) input_panel);
}

/**
 * @ingroup iface_input_panel
 *
 * Returns the surface of the corresponding input panel.
 */
static inline struct input_panel_surface *
input_panel_get_input_panel_surface(struct input_panel *input_panel, struct wl_surface *surface)
{
	struct wl_proxy *id;

	id = wl_proxy_marshal_flags((struct wl_proxy *) input_panel,
			 INPUT_PANEL_GET_INPUT_PANEL_SURFACE, &input_panel_surface_interface, wl_proxy_get_version((struct wl_proxy *) input_panel), 0, NULL, surface);

	return (struct input_panel_surface *) id;
}

#ifndef INPUT_PANEL_SURFACE_POSITION_ENUM
#define INPUT_PANEL_SURFACE_POSITION_ENUM
/**
 * @ingroup iface_input_panel_surface
 * position of input panel
 *
 * Position of an input panel.
 */
enum input_panel_surface_position {
	INPUT_PANEL_SURFACE_POSITION_CENTER_BOTTOM = 0,
};
#endif /* INPUT_PANEL_SURFACE_POSITION_ENUM */

#define INPUT_PANEL_SURFACE_SET_TOPLEVEL 0


/**
 * @ingroup iface_input_panel_surface
 */
#define INPUT_PANEL_SURFACE_SET_TOPLEVEL_SINCE_VERSION 1

/** @ingroup iface_input_panel_surface */
static inline void
input_panel_surface_set_user_data(struct input_panel_surface *input_panel_surface, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) input_panel_surface, user_data);
}

/** @ingroup iface_input_panel_surface */
static inline void *
input_panel_surface_get_user_data(struct input_panel_surface *input_panel_surface)
{
	return wl_proxy_get_user_data((struct wl_proxy *) input_panel_surface);
}

static inline uint32_t
input_panel_surface_get_version(struct input_panel_surface *input_panel_surface)
{
	return wl_proxy_get_version((struct wl_proxy *) input_panel_surface);
}

/** @ingroup iface_input_panel_surface */
static inline void
input_panel_surface_destroy(struct input_panel_surface *input_panel_surface)
{
	wl_proxy_destroy((struct wl_proxy *) input_panel_surface);
}

/**
 * @ingroup iface_input_panel_surface
 *
 * An input panel surface is only shown, when a text model is active.
 *
 * Not implemented.
 */
static inline void
input_panel_surface_set_toplevel(struct input_panel_surface *input_panel_surface, uint32_t position)
{
	wl_proxy_marshal_flags((struct wl_proxy *) input_panel_surface,
			 INPUT_PANEL_SURFACE_SET_TOPLEVEL, NULL, wl_proxy_get_version((struct wl_proxy *) input_panel_surface), 0, position);
}

#ifdef  __cplusplus
}
#endif

#endif
