/* Generated by wayland-scanner 1.20.0 */

#ifndef INPUT_METHOD_SERVER_PROTOCOL_H
#define INPUT_METHOD_SERVER_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-server.h"

#ifdef  __cplusplus
extern "C" {
#endif

struct wl_client;
struct wl_resource;

/**
 * @page page_input_method The input_method protocol
 * @section page_ifaces_input_method Interfaces
 * - @subpage page_iface_input_method_context - input method context
 * - @subpage page_iface_input_method - input method
 * - @subpage page_iface_input_panel - interface for implementing keyboards
 * - @subpage page_iface_input_panel_surface - 
 * @section page_copyright_input_method Copyright
 * <pre>
 *
 * Copyright © 2012 Intel Corporation
 * Copyright © 2013-2020 LG Electronics, Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that the above copyright notice appear in
 * all copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of
 * the copyright holders not be used in advertising or publicity
 * pertaining to distribution of the software without specific,
 * written prior permission.  The copyright holders make no
 * representations about the suitability of this software for any
 * purpose.  It is provided "as is" without express or implied
 * warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS, IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 * THIS SOFTWARE.
 * </pre>
 */
struct input_method;
struct input_method_context;
struct input_panel;
struct input_panel_surface;
struct wl_keyboard;
struct wl_surface;

#ifndef INPUT_METHOD_CONTEXT_INTERFACE
#define INPUT_METHOD_CONTEXT_INTERFACE
/**
 * @page page_iface_input_method_context input_method_context
 * @section page_iface_input_method_context_desc Description
 *
 * Corresponds to a text model on input method side. An input method context
 * is created on text mode activation on the input method side. It allows to
 * receive information about the text model from the application via events.
 * Input method contexts do not keep state after deactivation and should be
 * destroyed after deactivation is handled.
 * @section page_iface_input_method_context_api API
 * See @ref iface_input_method_context.
 */
/**
 * @defgroup iface_input_method_context The input_method_context interface
 *
 * Corresponds to a text model on input method side. An input method context
 * is created on text mode activation on the input method side. It allows to
 * receive information about the text model from the application via events.
 * Input method contexts do not keep state after deactivation and should be
 * destroyed after deactivation is handled.
 */
extern const struct wl_interface input_method_context_interface;
#endif
#ifndef INPUT_METHOD_INTERFACE
#define INPUT_METHOD_INTERFACE
/**
 * @page page_iface_input_method input_method
 * @section page_iface_input_method_desc Description
 *
 * An input method object is responsible to compose text in response to
 * input from hardware or virtual keyboards. There is one input method
 * object per seat. On activate there is a new input method context object
 * created which allows the input method to communicate with the text model.
 * @section page_iface_input_method_api API
 * See @ref iface_input_method.
 */
/**
 * @defgroup iface_input_method The input_method interface
 *
 * An input method object is responsible to compose text in response to
 * input from hardware or virtual keyboards. There is one input method
 * object per seat. On activate there is a new input method context object
 * created which allows the input method to communicate with the text model.
 */
extern const struct wl_interface input_method_interface;
#endif
#ifndef INPUT_PANEL_INTERFACE
#define INPUT_PANEL_INTERFACE
/**
 * @page page_iface_input_panel input_panel
 * @section page_iface_input_panel_desc Description
 *
 * Only one client can bind this interface at a time.
 * @section page_iface_input_panel_api API
 * See @ref iface_input_panel.
 */
/**
 * @defgroup iface_input_panel The input_panel interface
 *
 * Only one client can bind this interface at a time.
 */
extern const struct wl_interface input_panel_interface;
#endif
#ifndef INPUT_PANEL_SURFACE_INTERFACE
#define INPUT_PANEL_SURFACE_INTERFACE
/**
 * @page page_iface_input_panel_surface input_panel_surface
 * @section page_iface_input_panel_surface_api API
 * See @ref iface_input_panel_surface.
 */
/**
 * @defgroup iface_input_panel_surface The input_panel_surface interface
 */
extern const struct wl_interface input_panel_surface_interface;
#endif

/**
 * @ingroup iface_input_method_context
 * @struct input_method_context_interface
 */
struct input_method_context_interface {
	/**
	 * destroy object
	 *
	 * Destroys the input method context object.
	 */
	void (*destroy)(struct wl_client *client,
			struct wl_resource *resource);
	/**
	 * commit string
	 *
	 * Sends the commit string text to the applications text model.
	 */
	void (*commit_string)(struct wl_client *client,
			      struct wl_resource *resource,
			      uint32_t serial,
			      const char *text);
	/**
	 * pre-edit string
	 *
	 * Sends the pre-edit string text to the applications text model.
	 */
	void (*preedit_string)(struct wl_client *client,
			       struct wl_resource *resource,
			       uint32_t serial,
			       const char *text,
			       const char *commit);
	/**
	 * pre-edit styling
	 *
	 * Sets styling information on composing text. The style is
	 * applied for length (in bytes) characters from index relative to
	 * the beginning of the composing text (as byte index). Multiple
	 * styles can be applied to a composing text.
	 */
	void (*preedit_styling)(struct wl_client *client,
				struct wl_resource *resource,
				uint32_t serial,
				uint32_t index,
				uint32_t length,
				uint32_t style);
	/**
	 * pre-edit cursor
	 *
	 * Sets the cursor position inside the composing text (as byte
	 * index) relative to the start of the composing text.
	 */
	void (*preedit_cursor)(struct wl_client *client,
			       struct wl_resource *resource,
			       uint32_t serial,
			       int32_t index);
	/**
	 * delete surrounding text
	 *
	 * Deletes the surrounding text.
	 */
	void (*delete_surrounding_text)(struct wl_client *client,
					struct wl_resource *resource,
					uint32_t serial,
					int32_t index,
					uint32_t length);
	/**
	 * set cursor to new position
	 *
	 * Sets the cursor or anchor position.
	 *
	 * Not implemented.
	 */
	void (*cursor_position)(struct wl_client *client,
				struct wl_resource *resource,
				uint32_t serial,
				int32_t index,
				int32_t anchor);
	/**
	 * modifiers map
	 *
	 * Transfers an array of 0-terminated modifiers names. The
	 * position in the array is the index of the modifier as used in
	 * the modifiers bitmask in the keysym event.
	 */
	void (*modifiers_map)(struct wl_client *client,
			      struct wl_resource *resource,
			      struct wl_array *map);
	/**
	 * keysym
	 *
	 * Notifies when a key event was sent. Key events should not be
	 * used for normal text input operations, which should be done with
	 * commit_string, delete_surrounfing_text, etc. The key event
	 * follows the wl_keyboard key event convention. State is a XKB
	 * keysym, state a wl_keyboard key_state.
	 */
	void (*keysym)(struct wl_client *client,
		       struct wl_resource *resource,
		       uint32_t serial,
		       uint32_t time,
		       uint32_t sym,
		       uint32_t state,
		       uint32_t modifiers);
	/**
	 * grab hardware keyboard
	 *
	 * Allows an input method to receive hardware keyboard input and
	 * process key events to generate text events (with pre-edit) over
	 * the wire. This allows input methods which compose multiple key
	 * events for inputting text like it is done for CJK languages.
	 */
	void (*grab_keyboard)(struct wl_client *client,
			      struct wl_resource *resource,
			      uint32_t keyboard);
	/**
	 * forward key event
	 *
	 * Forwards a wl_keyboard::key event to the client that was not
	 * processed by the input method itself. Should be used when
	 * filtering key events with grab_keyboard. The arguments should be
	 * the ones from the wl_keyboard::key event.
	 */
	void (*key)(struct wl_client *client,
		    struct wl_resource *resource,
		    uint32_t serial,
		    uint32_t time,
		    uint32_t key,
		    uint32_t state);
	/**
	 * forward modifiers event
	 *
	 * Forwards a wl_keyboard::modifiers event to the client that was
	 * not processed by the input method itself. Should be used when
	 * filtering key events with grab_keyboard. The arguments should be
	 * the ones from the wl_keyboard::modifiers event.
	 */
	void (*modifiers)(struct wl_client *client,
			  struct wl_resource *resource,
			  uint32_t serial,
			  uint32_t mods_depressed,
			  uint32_t mods_latched,
			  uint32_t mods_locked,
			  uint32_t group);
};

#define INPUT_METHOD_CONTEXT_SURROUNDING_TEXT 0
#define INPUT_METHOD_CONTEXT_RESET 1
#define INPUT_METHOD_CONTEXT_CONTENT_TYPE 2
#define INPUT_METHOD_CONTEXT_INVOKE_ACTION 3
#define INPUT_METHOD_CONTEXT_COMMIT 4
#define INPUT_METHOD_CONTEXT_MAX_TEXT_LENGTH 5
#define INPUT_METHOD_CONTEXT_PLATFORM_DATA 6
#define INPUT_METHOD_CONTEXT_ENTER_KEY_TYPE 7

/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_SURROUNDING_TEXT_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_RESET_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_CONTENT_TYPE_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_INVOKE_ACTION_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_COMMIT_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_MAX_TEXT_LENGTH_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_PLATFORM_DATA_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_ENTER_KEY_TYPE_SINCE_VERSION 1

/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_COMMIT_STRING_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_PREEDIT_STRING_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_PREEDIT_STYLING_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_PREEDIT_CURSOR_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_DELETE_SURROUNDING_TEXT_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_CURSOR_POSITION_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_MODIFIERS_MAP_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_KEYSYM_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_GRAB_KEYBOARD_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_KEY_SINCE_VERSION 1
/**
 * @ingroup iface_input_method_context
 */
#define INPUT_METHOD_CONTEXT_MODIFIERS_SINCE_VERSION 1

/**
 * @ingroup iface_input_method_context
 * Sends an surrounding_text event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
input_method_context_send_surrounding_text(struct wl_resource *resource_, const char *text, uint32_t cursor, uint32_t anchor)
{
	wl_resource_post_event(resource_, INPUT_METHOD_CONTEXT_SURROUNDING_TEXT, text, cursor, anchor);
}

/**
 * @ingroup iface_input_method_context
 * Sends an reset event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
input_method_context_send_reset(struct wl_resource *resource_, uint32_t serial)
{
	wl_resource_post_event(resource_, INPUT_METHOD_CONTEXT_RESET, serial);
}

/**
 * @ingroup iface_input_method_context
 * Sends an content_type event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
input_method_context_send_content_type(struct wl_resource *resource_, uint32_t hint, uint32_t purpose)
{
	wl_resource_post_event(resource_, INPUT_METHOD_CONTEXT_CONTENT_TYPE, hint, purpose);
}

/**
 * @ingroup iface_input_method_context
 * Sends an invoke_action event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
input_method_context_send_invoke_action(struct wl_resource *resource_, uint32_t button, uint32_t index)
{
	wl_resource_post_event(resource_, INPUT_METHOD_CONTEXT_INVOKE_ACTION, button, index);
}

/**
 * @ingroup iface_input_method_context
 * Sends an commit event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
input_method_context_send_commit(struct wl_resource *resource_)
{
	wl_resource_post_event(resource_, INPUT_METHOD_CONTEXT_COMMIT);
}

/**
 * @ingroup iface_input_method_context
 * Sends an max_text_length event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
input_method_context_send_max_text_length(struct wl_resource *resource_, uint32_t length)
{
	wl_resource_post_event(resource_, INPUT_METHOD_CONTEXT_MAX_TEXT_LENGTH, length);
}

/**
 * @ingroup iface_input_method_context
 * Sends an platform_data event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
input_method_context_send_platform_data(struct wl_resource *resource_, const char *text)
{
	wl_resource_post_event(resource_, INPUT_METHOD_CONTEXT_PLATFORM_DATA, text);
}

/**
 * @ingroup iface_input_method_context
 * Sends an enter_key_type event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
input_method_context_send_enter_key_type(struct wl_resource *resource_, uint32_t enter_key_type)
{
	wl_resource_post_event(resource_, INPUT_METHOD_CONTEXT_ENTER_KEY_TYPE, enter_key_type);
}

/**
 * @ingroup iface_input_method
 * @struct input_method_interface
 */
struct input_method_interface {
	/**
	 * set display id
	 *
	 * Sets the id of the display corresponding.
	 * @param id display id
	 * @since 2
	 */
	void (*set_display_id)(struct wl_client *client,
			       struct wl_resource *resource,
			       uint32_t id);
};

#define INPUT_METHOD_ACTIVATE 0
#define INPUT_METHOD_DEACTIVATE 1
#define INPUT_METHOD_SHOW_INPUT_PANEL 2
#define INPUT_METHOD_HIDE_INPUT_PANEL 3

/**
 * @ingroup iface_input_method
 */
#define INPUT_METHOD_ACTIVATE_SINCE_VERSION 1
/**
 * @ingroup iface_input_method
 */
#define INPUT_METHOD_DEACTIVATE_SINCE_VERSION 1
/**
 * @ingroup iface_input_method
 */
#define INPUT_METHOD_SHOW_INPUT_PANEL_SINCE_VERSION 1
/**
 * @ingroup iface_input_method
 */
#define INPUT_METHOD_HIDE_INPUT_PANEL_SINCE_VERSION 1

/**
 * @ingroup iface_input_method
 */
#define INPUT_METHOD_SET_DISPLAY_ID_SINCE_VERSION 2

/**
 * @ingroup iface_input_method
 * Sends an activate event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
input_method_send_activate(struct wl_resource *resource_, struct wl_resource *id, uint32_t serial)
{
	wl_resource_post_event(resource_, INPUT_METHOD_ACTIVATE, id, serial);
}

/**
 * @ingroup iface_input_method
 * Sends an deactivate event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
input_method_send_deactivate(struct wl_resource *resource_, struct wl_resource *context)
{
	wl_resource_post_event(resource_, INPUT_METHOD_DEACTIVATE, context);
}

/**
 * @ingroup iface_input_method
 * Sends an show_input_panel event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
input_method_send_show_input_panel(struct wl_resource *resource_, struct wl_resource *context)
{
	wl_resource_post_event(resource_, INPUT_METHOD_SHOW_INPUT_PANEL, context);
}

/**
 * @ingroup iface_input_method
 * Sends an hide_input_panel event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
input_method_send_hide_input_panel(struct wl_resource *resource_, struct wl_resource *context)
{
	wl_resource_post_event(resource_, INPUT_METHOD_HIDE_INPUT_PANEL, context);
}

/**
 * @ingroup iface_input_panel
 * @struct input_panel_interface
 */
struct input_panel_interface {
	/**
	 * get input panel surface
	 *
	 * Returns the surface of the corresponding input panel.
	 */
	void (*get_input_panel_surface)(struct wl_client *client,
					struct wl_resource *resource,
					uint32_t id,
					struct wl_resource *surface);
};


/**
 * @ingroup iface_input_panel
 */
#define INPUT_PANEL_GET_INPUT_PANEL_SURFACE_SINCE_VERSION 1

#ifndef INPUT_PANEL_SURFACE_POSITION_ENUM
#define INPUT_PANEL_SURFACE_POSITION_ENUM
/**
 * @ingroup iface_input_panel_surface
 * position of input panel
 *
 * Position of an input panel.
 */
enum input_panel_surface_position {
	INPUT_PANEL_SURFACE_POSITION_CENTER_BOTTOM = 0,
};
#endif /* INPUT_PANEL_SURFACE_POSITION_ENUM */

/**
 * @ingroup iface_input_panel_surface
 * @struct input_panel_surface_interface
 */
struct input_panel_surface_interface {
	/**
	 * set the surface type as a keyboard
	 *
	 * An input panel surface is only shown, when a text model is
	 * active.
	 *
	 * Not implemented.
	 */
	void (*set_toplevel)(struct wl_client *client,
			     struct wl_resource *resource,
			     uint32_t position);
};


/**
 * @ingroup iface_input_panel_surface
 */
#define INPUT_PANEL_SURFACE_SET_TOPLEVEL_SINCE_VERSION 1

#ifdef  __cplusplus
}
#endif

#endif
